import rclpy
from rclpy.node import Node
from trajectory_msgs.msg import JointTrajectory, JointTrajectoryPoint
import time

class ScaledJointTrajectoryPublisher(Node):
    def __init__(self):
        super().__init__('scaled_joint_trajectory_publisher')
        self.publisher = self.create_publisher(
            JointTrajectory, 
            '/scaled_joint_trajectory_controller/joint_trajectory', 
            10
        )

        try:
            msg = JointTrajectory()
            msg.joint_names = [
                "shoulder_pan_joint", "shoulder_lift_joint", "elbow_joint",
                "wrist_1_joint", "wrist_2_joint", "wrist_3_joint"
            ]

            point = JointTrajectoryPoint()
            point.positions = [2.0]*6  # Target joint positions
            point.velocities = [2.0] * 6
            point.accelerations = [2.0] * 6
            #point.time_from_start.sec = int(2)
            #point.time_from_start.nanosec = int(0)
            msg.points.append(point)

            self.publisher.publish(msg)
        except Exception as e:
            print(f"Error publishing joint trajectory: {e}")

def main():
    rclpy.init()
    node = ScaledJointTrajectoryPublisher()

    # Move to a target position


    rclpy.spin(node)
    node.destroy_node()
    rclpy.shutdown()

if __name__ == '__main__':
    main()
